@@ -10,7 +10,7 @@ accuracy.kfold <- function(dir=NULL){
   fileName_vec <- sort(fileName_vec)
   noFiles <- length(fileName_vec)#count number of files
   #Read one of files and get pop names
-  result01 <- read.table(paste0(dir,fileName_vec[1]), header=T)
+  result01 <- read.table(paste0(dir,fileName_vec[1]), header=T, check.names = F)
   pops <- names(result01)[4:length(names(result01))] #read column name and get the pop names between 4th to last column
   noPops <- length(pops)#Number of pops
   #create vectors for saving data
@@ -28,9 +28,8 @@ accuracy.kfold <- function(dir=NULL){
     fold[i] <- unlist(strsplit(oneFileName[4],split=".txt"))
     df <- read.table(paste0(dir,fileName_vec[i]),header=T)
     #Calculate overall correct assignment rate
-    #df$pred.pop <- factor(df$pred.pop, levels=levels(df$origin.pop))#ensure $pred.pop column has the same levels with $origin.pop
-    levels(df$pred.pop) <- pops
-    levels(df$origin.pop) <- pops
+    df$origin.pop <- factor(df$origin.pop, levels=levels(factor(pops)))#ensure origin/pred pop still keeps the same levels as input pops
+    df$pred.pop <- factor(df$pred.pop, levels=levels(factor(pops)))#which allows to handle test individuals not assigned to every pop
     ctable <- table(df$origin.pop,df$pred.pop)#make contingency table
     ftable <- as.data.frame(ctable)#convert table to data frame with frequency column
     totalSample <- sum(ftable$Freq)
